@@ -159,7 +159,7 @@ impl Drop for Context {
 }
 
 pub struct Hasher {
-    _context: Arc<Context>,
+    context: Arc<Context>,
     vm: *mut randomx_vm,
 }
 
@@ -170,12 +170,16 @@ impl Hasher {
     pub fn new(context: Arc<Context>) -> Self {
         unsafe {
             Hasher {
-                _context: Arc::clone(&context),
+                context: Arc::clone(&context),
                 vm: randomx_create_vm(context.flags, context.cache, context.dataset),
             }
         }
     }
 
+    pub fn context(&self) -> &Context {
+        &self.context
+    }
+
     pub fn hash(&self, inp: &[u8]) -> Output {
         let mut hash = [0u8; RANDOMX_HASH_SIZE as usize];
         unsafe {
